summaryrefslogtreecommitdiff
path: root/jstests/noPassthrough/catalog_shard_resharding_fixture.js
diff options
context:
space:
mode:
Diffstat (limited to 'jstests/noPassthrough/catalog_shard_resharding_fixture.js')
-rw-r--r--jstests/noPassthrough/catalog_shard_resharding_fixture.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/jstests/noPassthrough/catalog_shard_resharding_fixture.js b/jstests/noPassthrough/catalog_shard_resharding_fixture.js
index 201159086c1..4623764eb75 100644
--- a/jstests/noPassthrough/catalog_shard_resharding_fixture.js
+++ b/jstests/noPassthrough/catalog_shard_resharding_fixture.js
@@ -1,5 +1,5 @@
/**
* Test the ReshardingTest fixture can work with a catalogShard.
*
* @tags: [
* requires_fcv_70,
@@ -14,7 +14,7 @@
load("jstests/sharding/libs/resharding_test_fixture.js");
const reshardingTest =
- new ReshardingTest({numDonors: 2, numRecipients: 2, reshardInPlace: true, catalogShard: true});
+ new ReshardingTest({numDonors: 2, numRecipients: 2, reshardInPlace: true, configShard: true});
reshardingTest.setup();
const ns = "reshardingDb.coll";
@@ -1,5 +1,5 @@
/**
- * Test the ReshardingTest fixture can work with a catalogShard.
+ * Test the ReshardingTest fixture can work with a configShard.
*
* @tags: [